@@ -1,5 +1,4 @@
-#if SLANG_VERSION < 20000
-
+#if SLANG_VERSION < 20000 /* {{{ */
 #define SLclass_get_class_id(x)	(x)->cl_data_type
 #define SLang_get_error()	SLang_Error
 #define SLang_set_error(x)	(SLang_Error = (x))
@@ -11,11 +10,9 @@
 #define SLutf8_enable(x)	x
 #define SLang_pop_struct	_SLang_pop_struct
 #define SLang_free_struct	_SLstruct_delete_struct
-
-#ifdef __cplusplus
-extern "C"
-#endif
-
-int _SLstack_depth(void);
 #define SLstack_depth		_SLstack_depth
-#endif
+#define SLuindex_Type		unsigned int
+#define SLindex_Type		int
+extern LINKAGE int _SLstack_depth(void);
+#endif /* }}} */
+
